BirthDateFormField class
Three-field date input compatible with Form.
Returns DateTime (local, 00:00) when all three parts form a valid
calendar date. Otherwise returns null via FormField.value.
Customise appearance with theme, language with localizations, and field arrangement with fieldOrder.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FormField<
DateTime> - BirthDateFormField
Constructors
-
BirthDateFormField({Key? key, DateTime? initialValue, FormFieldSetter<
DateTime> ? onSaved, FormFieldValidator<DateTime> ? validator, ValueChanged<DateTime?> ? onChanged, AutovalidateMode? autovalidateMode, bool enabled = true, String? labelText, TextStyle? labelStyle, EdgeInsets labelPadding = EdgeInsets.zero, int minYear = 1900, int? maxYear, int? minAgeYears, int errorMaxLines = 2, BirthDateTheme theme = const BirthDateTheme(), BirthDateLocalizations localizations = const BirthDateLocalizations.en(), BirthDateFieldOrder fieldOrder = BirthDateFieldOrder.dmy})
Properties
- autovalidateMode → AutovalidateMode
-
Used to enable/disable this form field auto validation and update its
error text.
finalinherited
-
builder
→ FormFieldBuilder<
DateTime> -
Function that returns the widget representing this form field.
finalinherited
- enabled → bool
-
Whether the form is able to receive user input.
finalinherited
- errorBuilder → FormFieldErrorBuilder?
-
Function that returns the widget representing the error to display.
finalinherited
- errorMaxLines → int
-
final
- fieldOrder → BirthDateFieldOrder
-
Display order of the day, month, and year fields.
final
- forceErrorText → String?
-
An optional property that forces the FormFieldState into an error state
by directly setting the FormFieldState.errorText property without
running the validator function.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialValue → DateTime?
-
An optional value to initialize the form field to, or null otherwise.
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelPadding → EdgeInsets
-
final
- labelStyle → TextStyle?
-
final
- labelText → String?
-
final
- localizations → BirthDateLocalizations
-
Localized strings. Defaults to English.
final
- maxYear → int
-
final
- minAgeYears → int?
-
final
- minYear → int
-
final
-
onChanged
→ ValueChanged<
DateTime?> ? -
final
- onReset → VoidCallback?
-
An optional method to call when the form field is reset via
FormFieldState.reset.
finalinherited
-
onSaved
→ FormFieldSetter<
DateTime> ? -
An optional method to call with the final value when the form is saved via
FormState.save.
finalinherited
- restorationId → String?
-
Restoration ID to save and restore the state of the form field.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → BirthDateTheme
-
Visual customization. Defaults to BirthDateTheme defaults.
final
-
validator
→ FormFieldValidator<
DateTime> ? -
An optional method that validates an input. Returns an error string to
display if the input is invalid, or null otherwise.
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → FormFieldState< DateTime> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultValidator(
DateTime? value, {required int minYear, required int maxYear, int? minAgeYears, BirthDateLocalizations localizations = const BirthDateLocalizations.en()}) → String? - Default validator used when no custom validator is provided.